summaryrefslogtreecommitdiff
path: root/cmake/CheckGit.cmake
diff options
context:
space:
mode:
authorDominick Allen <djallen@librehumanitas.org>2024-10-21 12:49:43 -0500
committerDominick Allen <djallen@librehumanitas.org>2024-10-21 12:49:43 -0500
commitb2dbcb55e2832c373fecb4033a3ed77e5dbc77aa (patch)
tree1f294fcf1d85a02db86de3eea2b03393fd89ca5a /cmake/CheckGit.cmake
parent6a27a2a4032e88fa9154ef0f0741edc584f7a701 (diff)
Add vector and option.
Diffstat (limited to 'cmake/CheckGit.cmake')
-rw-r--r--cmake/CheckGit.cmake14
1 files changed, 7 insertions, 7 deletions
diff --git a/cmake/CheckGit.cmake b/cmake/CheckGit.cmake
index f7d8bce..46736e7 100644
--- a/cmake/CheckGit.cmake
+++ b/cmake/CheckGit.cmake
@@ -7,8 +7,8 @@ if (NOT DEFINED post_configure_dir)
set(post_configure_dir ${CMAKE_BINARY_DIR}/include)
endif ()
-set(pre_configure_file ${pre_configure_dir}/fud_version.hpp.in)
-set(post_configure_file ${post_configure_dir}/fud_version.hpp)
+set(pre_configure_file ${pre_configure_dir}/fud_config.hpp.in)
+set(post_configure_file ${post_configure_dir}/fud_config.hpp)
function(CheckGitWrite git_hash)
file(WRITE ${CMAKE_BINARY_DIR}/git-state.txt ${git_hash})
@@ -37,15 +37,15 @@ function(CheckGitVersion git_hash)
file(MAKE_DIRECTORY ${post_configure_dir})
endif ()
- # if (NOT EXISTS ${post_configure_dir}/fud_version.h)
- # file(COPY ${pre_configure_dir}/fud_version.h DESTINATION ${post_configure_dir})
+ # if (NOT EXISTS ${post_configure_dir}/fud_config.h)
+ # file(COPY ${pre_configure_dir}/fud_config.h DESTINATION ${post_configure_dir})
# endif()
if (NOT DEFINED GIT_HASH_CACHE)
set(GIT_HASH_CACHE "INVALID")
endif ()
# Only update the fud_version.cpp if the hash has changed. This will
# prevent us from rebuilding the project more than we need to.
if (NOT ${GIT_HASH} STREQUAL ${GIT_HASH_CACHE} OR NOT EXISTS ${post_configure_file})
# Set che GIT_HASH_CACHE variable the next build won't have
@@ -70,8 +70,8 @@ function(CheckGitSetup top_git_hash)
BYPRODUCTS ${post_configure_file}
)
- add_library(fud_version INTERFACE ${CMAKE_BINARY_DIR}/include/fud_version.hpp)
- add_dependencies(fud_version AlwaysCheckGit)
+ add_library(fud_config INTERFACE ${CMAKE_BINARY_DIR}/include/fud_config.hpp)
+ add_dependencies(fud_config AlwaysCheckGit)
CheckGitVersion(git_hash)
set(${top_git_hash} ${git_hash} PARENT_SCOPE)
@@ -37,15 +37,15 @@ function(CheckGitVersion git_hash)
set(GIT_HASH_CACHE "INVALID")
endif ()
- # Only update the fud_version.cpp if the hash has changed. This will
+ # Only update the fud_config.cpp if the hash has changed. This will
# prevent us from rebuilding the project more than we need to.
if (NOT ${GIT_HASH} STREQUAL ${GIT_HASH_CACHE} OR NOT EXISTS ${post_configure_file})